Struct rafx_base::atomic_once_cell::AtomicOnceCell [−][src]
pub struct AtomicOnceCell<T> { /* fields omitted */ }Expand description
A thread-safe container that does not require default initialization. The cell may be initialized
with set and then retrieved as a reference with get. Calling set is thread-safe. The cell
will panic if the set function is called more than once. The cell will only drop initialized elements.
Guarantees
- The allocated memory will not be
defaultinitialized. - Elements initialized by
setare immutable. - The synchronization is
lock-free.
Implementations
impl<T> AtomicOnceCell<T>[src]
impl<T> AtomicOnceCell<T>[src]Trait Implementations
impl<T> Drop for AtomicOnceCell<T>[src]
impl<T> Drop for AtomicOnceCell<T>[src]impl<T> Sync for AtomicOnceCell<T>[src]