| AtomicOnceCellArray | A fixed-size array with capacity determined at run-time. The elements of the array are uninitialized.
Elements may be initialized with set and then retrieved as a reference with get. Calling set is
thread-safe. The array will panic if the capacity is exceeded, or the index is out of range, or the
set function is called more than once on an index when T is not zero-sized. The array will only drop
initialized elements.
|