Struct rafx_base::resource_map::ResourceId [−][src]
pub struct ResourceId { /* fields omitted */ }Expand description
Every type can be converted to a ResourceId. The ResourceId is used to look up the type’s value
in the ResourceMap
Implementations
impl ResourceId[src]
impl ResourceId[src]Trait Implementations
impl Clone for ResourceId[src]
impl Clone for ResourceId[src]fn clone(&self) -> ResourceId[src]
fn clone(&self) -> ResourceId[src]Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]Performs copy-assignment from source. Read more
impl Debug for ResourceId[src]
impl Debug for ResourceId[src]impl Hash for ResourceId[src]
impl Hash for ResourceId[src]impl Ord for ResourceId[src]
impl Ord for ResourceId[src]impl PartialEq<ResourceId> for ResourceId[src]
impl PartialEq<ResourceId> for ResourceId[src]fn eq(&self, other: &ResourceId) -> bool[src]
fn eq(&self, other: &ResourceId) -> bool[src]This method tests for self and other values to be equal, and is used
by ==. Read more
fn ne(&self, other: &ResourceId) -> bool[src]
fn ne(&self, other: &ResourceId) -> bool[src]This method tests for !=.
impl PartialOrd<ResourceId> for ResourceId[src]
impl PartialOrd<ResourceId> for ResourceId[src]fn partial_cmp(&self, other: &ResourceId) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &ResourceId) -> Option<Ordering>[src]This method returns an ordering between self and other values if one exists. Read more
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn lt(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than (for self and other) and is used by the < operator. Read more
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]fn le(&self, other: &Rhs) -> bool1.0.0[src]This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ResourceId[src]
impl StructuralEq for ResourceId[src]
impl StructuralPartialEq for ResourceId[src]