Struct rafx_base::resource_ref_map::ResourceRefMap [−][src]
pub struct ResourceRefMap<'a> { /* fields omitted */ }Expand description
Like ResourceMap, but the insertions are temporary. This is an alternative to making a large
amount of code generic just to pass down an arbitrary
Implementations
impl<'a> ResourceRefMap<'a>[src]
impl<'a> ResourceRefMap<'a>[src]pub fn new() -> Self[src]
pub fn insert<R>(&mut self, r: &'a mut R) where
R: Resource, [src]
pub fn insert<R>(&mut self, r: &'a mut R) where
R: Resource, [src]Add a type/resource instance to the map
pub fn remove<R>(&mut self) -> Option<&'a mut R> where
R: Resource, [src]
pub fn remove<R>(&mut self) -> Option<&'a mut R> where
R: Resource, [src]Remove a type/resource instance from the map
pub fn fetch<R: Resource>(&self) -> ResourceRefBorrow<'_, R>[src]
pub fn fetch<R: Resource>(&self) -> ResourceRefBorrow<'_, R>[src]Read-only fetch of a resource. Trying to get a resource that is not in the map is fatal. Use try_fetch if unsure whether the resource exists. Requesting read access to a resource that has any concurrently active writer is fatal.
pub fn try_fetch<R: Resource>(&self) -> Option<ResourceRefBorrow<'_, R>>[src]
pub fn try_fetch<R: Resource>(&self) -> Option<ResourceRefBorrow<'_, R>>[src]Read-only fetch of a resource. Requesting read access to a resource that has a concurrently active writer is fatal. Returns None if the type is not registered.
pub fn fetch_mut<R: Resource>(&self) -> ResourceRefBorrowMut<'_, R>[src]
pub fn fetch_mut<R: Resource>(&self) -> ResourceRefBorrowMut<'_, R>[src]Read/Write fetch of a resource. Trying to get a resource that is not in the map is fatal. Use try_fetch if unsure whether the resource exists. Requesting write access to a resource with any concurrently active read/write is fatal
pub fn try_fetch_mut<R: Resource>(&self) -> Option<ResourceRefBorrowMut<'_, R>>[src]
pub fn try_fetch_mut<R: Resource>(&self) -> Option<ResourceRefBorrowMut<'_, R>>[src]Read/Write fetch of a resource. Requesting write access to a resource with any concurrently active read/write is fatal. Returns None if the type is not registered.