Struct rafx_base::atomic_once_cell_array::AtomicOnceCellArray [−][src]
pub struct AtomicOnceCellArray<T> { /* fields omitted */ }Expand description
A fixed-size array with capacity determined at run-time. The elements of the array are uninitialized.
Elements may be initialized with set and then retrieved as a reference with get. Calling set is
thread-safe. The array will panic if the capacity is exceeded, or the index is out of range, or the
set function is called more than once on an index when T is not zero-sized. The array will only drop
initialized elements.
Guarantees
- The array will not allocate if
capacityis 0 or ifTis zero-sized. - The allocated memory will not be
defaultinitialized. - Elements initialized by
setare immutable. - The synchronization is
lock-free.
Zero-sized Types
When T is zero-sized, the array does not track individual indices and instead only maintains a count of
how many instances of T have been set in the array. On drop, the array will drop that many instances
of T. The array will panic if the number of calls to set exceeds the capacity.
Implementations
impl<T> AtomicOnceCellArray<T>[src]
impl<T> AtomicOnceCellArray<T>[src]Trait Implementations
impl<T> Drop for AtomicOnceCellArray<T>[src]
impl<T> Drop for AtomicOnceCellArray<T>[src]impl<T> Sync for AtomicOnceCellArray<T>[src]