Struct rafx_base::atomic_once_cell_stack::AtomicOnceCellStack [−][src]
pub struct AtomicOnceCellStack<T> { /* fields omitted */ }Expand description
A fixed-size stack with capacity determined at run-time. The elements of the stack are uninitialized.
Elements may be initialized with push and then retrieved as a reference with get. push returns the
index of the element in the stack. The caller may reserve space for multiple elements with reserve_uninit.
Reserved elements must be initialized with set. Calling push, reserve_uninit, or set is thread-safe.
The stack will panic if the capacity is exceeded, or the index is out of range, or the set function is
called more than once on an index when T is not zero-sized, or if the set function is called on an index
that was not reserved by a prior call to reserve_uninit. The stack will only drop initialized elements.
Guarantees
- The stack will not allocate if
capacityis 0 or ifTis zero-sized. - The allocated memory will not be
defaultinitialized. - Elements initialized by
pushorsetare immutable. - The synchronization is
lock-free.
Zero-sized Types
When T is zero-sized, the stack does not track individual indices and instead only maintains a count of
how many instances of T have been set in the stack. On drop, the stack will drop that many instances
of T. The stack will panic if the number of calls to set exceeds the capacity.
Implementations
impl<T> AtomicOnceCellStack<T>[src]
impl<T> AtomicOnceCellStack<T>[src]pub fn with_capacity(capacity: usize) -> Self[src]
pub fn push(&self, val: T) -> usize[src]
pub fn reserve_uninit(&self, num_to_reserve: usize) -> usize[src]
pub fn set(&self, index: usize, val: T)[src]
pub fn get(&self, index: usize) -> &T[src]
pub fn capacity(&self) -> usize[src]
pub fn len(&self) -> usize[src]
pub fn iter(&self) -> Iter<'_, T>ⓘ[src]