Struct rafx_base::trust_cell::Ref [−][src]
An immutable reference to data in a TrustCell.
Access the value via std::ops::Deref (e.g. *val)
Fields
value: &'a TImplementations
impl<'a, T: ?Sized> Ref<'a, T>[src]
impl<'a, T: ?Sized> Ref<'a, T>[src]pub fn map<U, F>(self, f: F) -> Ref<'a, U> where
F: FnOnce(&T) -> &U,
U: ?Sized, [src]
pub fn map<U, F>(self, f: F) -> Ref<'a, U> where
F: FnOnce(&T) -> &U,
U: ?Sized, [src]Makes a new Ref for a component of the borrowed data which preserves
the existing borrow.
The TrustCell is already immutably borrowed, so this cannot fail.
This is an associated function that needs to be used as Ref::map(...).
A method would interfere with methods of the same name on the contents
of a Ref used through Deref. Further this preserves the borrow of
the value and hence does the proper cleanup when it’s dropped.
Examples
This can be used to avoid pointer indirection when a boxed item is
stored in the TrustCell.
use rafx_base::trust_cell::{Ref, TrustCell}; let cb = TrustCell::new(Box::new(5)); // Borrowing the cell causes the `Ref` to store a reference to the `Box`, which is a // pointer to the value on the heap, not the actual value. let boxed_ref: Ref<'_, Box<usize>> = cb.borrow(); assert_eq!(**boxed_ref, 5); // Notice the double deref to get the actual value. // By using `map` we can let `Ref` store a reference directly to the value on the heap. let pure_ref: Ref<'_, usize> = Ref::map(boxed_ref, Box::as_ref); assert_eq!(*pure_ref, 5);
We can also use map to get a reference to a sub-part of the borrowed
value.
let c = TrustCell::new((5, 'b')); let b1: Ref<'_, (u32, char)> = c.borrow(); let b2: Ref<'_, u32> = Ref::map(b1, |t| &t.0); assert_eq!(*b2, 5);