Struct rafx_base::trust_cell::RefMut [−][src]
pub struct RefMut<'a, T: ?Sized + 'a> { /* fields omitted */ }
A mutable reference to data in a TrustCell.
Access the value via std::ops::DerefMut (e.g. *val)
Implementations
impl<'a, T: ?Sized> RefMut<'a, T>[src]
impl<'a, T: ?Sized> RefMut<'a, T>[src]pub fn map<U, F>(self, f: F) -> RefMut<'a, U> where
F: FnOnce(&mut T) -> &mut U,
U: ?Sized, [src]
pub fn map<U, F>(self, f: F) -> RefMut<'a, U> where
F: FnOnce(&mut T) -> &mut U,
U: ?Sized, [src]Makes a new RefMut for a component of the borrowed data which
preserves the existing borrow.
The TrustCell is already mutably borrowed, so this cannot fail.
This is an associated function that needs to be used as
RefMut::map(...). A method would interfere with methods of the
same name on the contents of a RefMut used through DerefMut.
Further this preserves the borrow of the value and hence does the
proper cleanup when it’s dropped.
Examples
This can also be used to avoid pointer indirection when a boxed item is
stored in the TrustCell.
use rafx_base::trust_cell::{RefMut, TrustCell}; let cb = TrustCell::new(Box::new(5)); // Borrowing the cell causes the `RefMut` to store a reference to the `Box`, which is a // pointer to the value on the heap, and not a reference directly to the value. let boxed_ref: RefMut<'_, Box<usize>> = cb.borrow_mut(); assert_eq!(**boxed_ref, 5); // Notice the double deref to get the actual value. // By using `map` we can let `RefMut` store a reference directly to the value on the heap. let pure_ref: RefMut<'_, usize> = RefMut::map(boxed_ref, Box::as_mut); assert_eq!(*pure_ref, 5);
We can also use map to get a reference to a sub-part of the borrowed
value.
let c = TrustCell::new((5, 'b')); let b1: RefMut<'_, (u32, char)> = c.borrow_mut(); let b2: RefMut<'_, u32> = RefMut::map(b1, |t| &mut t.0); assert_eq!(*b2, 5);